@@ -11,10 +11,12 @@ import datetime
 import decimal
 import functools
 import itertools
+import math
 import operator
 import uuid
 from typing import Any, Mapping, MutableMapping, Sequence, TypeVar
 
+import ibis
 import ibis.expr.datatypes as dt
 import ibis.expr.operations as ops
 import ibis.expr.schema as sch
@@ -1054,3 +1056,66 @@ def _extractdatefield(
     scalar_func.arguments.add(enum=stalg.FunctionArgument.Enum(specified=span))
     scalar_func.arguments.extend(arguments)
     return stalg.Expression(scalar_function=scalar_func)
+
+
+@translate.register(ops.Log)
+def _log(
+    op: ops.Log,
+    expr: ir.TableExpr,
+    compiler: SubstraitCompiler,
+    **kwargs: Any,
+) -> stalg.Expression:
+    arg = stalg.FunctionArgument(value=translate(op.arg, compiler, **kwargs))
+    base = stalg.FunctionArgument(
+        value=translate(
+            op.base if op.base is not None else ibis.literal(math.e), compiler, **kwargs
+        )
+    )
+
+    scalar_func = stalg.Expression.ScalarFunction(
+        function_reference=compiler.function_id(expr),
+        output_type=translate(expr.type()),
+        arguments=[arg, base],
+    )
+    return stalg.Expression(scalar_function=scalar_func)
+
+
+@translate.register(ops.FloorDivide)
+def _floordivide(
+    op: ops.FloorDivide,
+    expr: ir.TableExpr,
+    compiler: SubstraitCompiler,
+    **kwargs: Any,
+) -> stalg.Expression:
+    left, right = op.left, op.right
+    return translate((left / right).floor(), compiler, **kwargs)
+
+
+@translate.register(ops.Clip)
+def _clip(
+    op: ops.Clip,
+    expr: ir.TableExpr,
+    compiler: SubstraitCompiler,
+    **kwargs: Any,
+) -> stalg.Expression:
+    arg, lower, upper = op.arg, op.lower, op.upper
+
+    if lower is not None and upper is not None:
+        return translate(
+            (arg >= lower).ifelse((arg <= upper).ifelse(arg, upper), lower),
+            compiler,
+            **kwargs,
+        )
+    elif lower is not None:
+        return translate(
+            (arg >= lower).ifelse(arg, lower),
+            compiler,
+            **kwargs,
+        )
+    elif upper is not None:
+        return translate(
+            (arg <= upper).ifelse(arg, upper),
+            compiler,
+            **kwargs,
+        )
+    assert False
